# season

Determine the season for a given date.

See {doc}`../examples/season` for usage examples.

## API Reference

```{eval-rst}
.. automodule:: pyedautils.season
   :members:
   :undoc-members:
   :show-inheritance:
```
